<?php
/*
Defines the methods that all DAOs must implement.
*/
interface IDatabaseDao{
  public function begin();
  public function commit();
  public function rollback();
  public function close();
  
  /*
  Returns a list of dates of all data file groups that have already been imported.
  returns: an array with strings in YYYYMMDD format
  */
  public function getAlreadyImportedFilesDates();
	
  /*
  Inserts new planet data into the database.
  $planet = planet data to insert
  $imported_file_id = the database ID of the data file group to which this planet info belongs.
  returns: the ID of the planet
  */
  public function addPlanetData(/*Planet*/ $planet, $imported_file_id);
  
  /*
  Inserts new player data into the database.
  $planet = player data to insert
  $imported_file_id = the database ID of the data file group to which this player info belongs.
  returns: the ID of the player
  */
  public function addPlayerData(/*Player*/ $player, $imported_file_id);
  
  /*
  Inserts new alliance data into the database.
  $planet = alliance data to insert
  $imported_file_id = the database ID of the data file group to which this alliance info belongs.
  returns: the ID of the alliance
  */
  public function addAllianceData(/*Alliance*/ $alliance, $imported_file_id);
  
  /*
  Inserts new event data into the database.
  $planet = event data to insert
  $imported_file_id = the database ID of the data file group to which this event info belongs.
  returns: the ID of the event
  */
  public function addEventData(/*Event*/ $event, $imported_file_id);
  
  /*
  Inserts a new data file group record into the database.
  $date = the date of the group in YYYYMMDD format
  returns: the ID of the data file group
  */
  public function addImportedFile(/*"yyyymmdd"*/ $date);
}
?>
