<?php
require_once 'Alliance.php';
require_once 'DataFileGroup.php';
require_once 'Event.php';
require_once 'Planet.php';
require_once 'Player.php';
require_once 'MySqlDatabaseDao.php';

/*
Reads the information in the datafiles into the database.
$data_file_dir = directory where the data files are stored
$db_host = database host
$db_username = database username
$db_password = database password
$db_name = database name
*/
function main($data_file_dir, $db_host, $db_username, $db_password, $db_name, $game){
  //$data_file_dir must end in '/'
  if ($data_file_dir[strlen($data_file_dir)-1] != '/'){
    $data_file_dir .= '/';
  }
  
  //create the DAO
  $dao = new MySqlDatabaseDao($db_host, $db_username, $db_password, $db_name);
  
  //figure out which data files were already imported
  $already_imported_dates = $dao->getAlreadyImportedFilesDates();
  
  //import data
  $all_data_files = getDataFileGroups($game, $data_file_dir);
  foreach ($all_data_files as $date=>$data_file_group){
    
    //import the data file group if (1) it hasn't already been imported and (2) all its four data files are there 
    if (!in_array($date, $already_imported_dates) && $data_file_group->hasAllFiles()){
      try{
        echo "importing $date...\n";
        $dao->begin();
        
        $imported_file_id = $dao->addImportedFile($date);
        
        //players
        echo "   players...";
        $lines = gzfile($data_file_group->players);
        foreach ($lines as $line){
          if ($line[0] != '#'){
            $line = rtrim($line);
            $planet = new Player($line);
            $id = $dao->addPlayerData($planet, $imported_file_id);
          }
        }
        echo "done\n";
        
        //alliances
        echo "   alliances...";
        $lines = gzfile($data_file_group->alliances);
        $group = array();
        foreach ($lines as $line){
          $line = rtrim($line);
          if ($line[0] != '#'){
            if ( (count($group) == 0 || count($group) == 2) && $line == '' ){
              //only the description line (index 1 in $group) can be blank...skip any other lines that are blank
              //account for the odd bug that appeared 20090711 where one entry had four lines
              /*
              (.) Sodomie.
              &#9794; + &#9792; => (.) => (x) => (o) => (O)
              
              Titch -3 -81 0 0
              */
              continue;
            }
            $group[] = $line;
          }
          if (count($group) == 3){
            $alliance = new Alliance($group);
            $id = $dao->addAllianceData($alliance, $imported_file_id);
            $group = array();
          }
        }
        echo "done\n";
        
        //planets
        echo "   planets...";
        $lines = gzfile($data_file_group->planets);
        foreach ($lines as $line){
          if ($line[0] != '#'){
            $line = rtrim($line);
            $planet = new Planet($line);
            $id = $dao->addPlanetData($planet, $imported_file_id);
          }
        }
        echo "done\n";
        
        //events
        echo "   events...";
        $lines = gzfile($data_file_group->events);
        foreach ($lines as $line){
          if ($line[0] != '#'){
            $line = rtrim($line);
            $event = new Event($line);
            $id = $dao->addEventData($event, $imported_file_id);
          }
        }
        echo "done\n";
        
        $dao->commit();
      } catch (Exception $e){
        echo $e->getMessage() . "\n";
        $dao->rollback();
      }
    }
  }
  
  $dao->close();
}

/*
Builds a list of all data file groups, whose data files are in the data file directory.
$dir = the data file directory
returns: an associative array; key = date in YYYYMMDD format; value = DataFileGroup object
*/
function getDataFileGroups($game, $dir){
  $data_files = array();
  
  $files = scandir($dir);
  foreach ($files as $f){
    if (ereg("$game-([0-9]{8})-(planets|players|alliances|events)\\.txt\\.gz", $f, $regs) !== FALSE){
      if (!isset($data_files[$regs[1]])){
        $data_files[$regs[1]] = new DataFileGroup();
      }
      $group = $data_files[$regs[1]];
      
      $d = $dir . $regs[0];
      if ($regs[2] == 'planets'){
        $group->planets = $d;
      } else if ($regs[2] == 'players'){
        $group->players = $d;
      } else if ($regs[2] == 'alliances'){
        $group->alliances = $d;
      } else if ($regs[2] == 'events'){
        $group->events = $d;
      }
    }
  }
  
  return $data_files;
}

/*
Same as mysql_query(), but throws an Exception with the failed query if the query fails.
*/
function _mysql_query($query){
  $result = mysql_query($query);
  if ($result === false){
    throw new Exception(mysql_error() . ": [$query]\n");
  }
  return $result;
}
?>
