create table imported_files(
  id int unsigned auto_increment primary key,
  date date not null
);

create table players(
  id int unsigned auto_increment primary key,
  name varchar(50) unique key not null,
  location varchar(50) not null
);

create table player_histories(
  id int unsigned auto_increment primary key,
  player_id int unsigned not null references players(id),
  imported_file_id int unsigned not null references imported_files(id),
  influ_rank int unsigned not null,
  influ_rank_sc int unsigned not null,
  influ_score int unsigned not null,
  hyp_rank int unsigned not null,
  idr_rank int unsigned not null,
  idr_score int unsigned not null,
  idr_rank_sc int unsigned not null,
  sc int unsigned not null
);

create table alliances(
  id int unsigned auto_increment primary key,
  name varchar(50) not null,
  tag varchar(5) unique key not null,
  description varchar(128) not null
);

create table alliance_histories(
  id int unsigned auto_increment primary key,
  alliance_id int unsigned not null references alliances(id),
  imported_file_id int unsigned not null references imported_files(id),
  president_id int unsigned references players(id), /* can be null because sometimes a planet has a tag to an alliances that doesn't exist in the alliance data file for some reason (?) */
  avg_x int not null,
  avg_y int not null,
  nb_planets int unsigned not null,
  total_influence int unsigned not null
);

create table planets(
  id int unsigned auto_increment primary key,
  hyp_id int unsigned unique key not null,
  race tinyint unsigned not null,
  prod_type tinyint unsigned not null
);

create table planet_histories(
  id int unsigned auto_increment primary key,
  planet_id int unsigned not null references planets(id),
  imported_file_id int unsigned not null references imported_files(id),
  name varchar(50) not null,
  x int not null,
  y int not null,
  gov_system tinyint unsigned not null,
  activity int unsigned not null,
  alliance_id int unsigned references alliances(id),
  civ_level tinyint unsigned not null,
  planet_size tinyint unsigned not null
);

create table events(
  id int unsigned auto_increment primary key,
  planet_id int unsigned not null references planets(id),
  imported_file_id int unsigned not null references imported_files(id),
  date datetime not null,
  description varchar(128),
  hash char(32) unique key not null
);
